@@ -9,7 +9,7 @@ use constant CRYP_CHARS          => q{.}, q{,}, q{/}, 0..9, q{A}..q{Z}, q{a}..q{
 use constant RANDOM_NUM          => 64;
 use Carp qw( croak );
 
-our $VERSION = '1.22';
+our $VERSION = '1.23';
 
 our $RE = qr{\A\w\./}xms; # regex for passwords
 our $FATAL_HEADER;
@@ -138,9 +138,6 @@ sub _init {
       page_logoff_link 
       page_content 
       page_title
-      _TEMPLATE_TITLE
-      _TEMPLATE_TITLE_USER
-      _TEMPLATE_NAMES
    );
 
    return;
@@ -668,8 +665,8 @@ or you can just say:
 
 =head1 DESCRIPTION
 
-This document describes version C<1.22> of C<CGI::Auth::Basic>
-released on C<27 August 2012>.
+This document describes version C<1.23> of C<CGI::Auth::Basic>
+released on C<21 January 2015>.
 
 This module adds a simple (may be a little complex if you use all
 features) user validation system on top of your program. If you have 
@@ -967,11 +964,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2004 - 2015 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.12.3 or,
+it under the same terms as Perl itself, either Perl version 5.16.2 or,
 at your option, any later version of Perl 5 you may have available.
 =cut
